package Daje::Database::Model;
use v5.40;

# NAME
# ====
#
# Daje::Database::Model - It's the Daje database classes
#
# SYNOPSIS
# ========
#
#     use Daje::Database::Model;
#
# DESCRIPTION
# ===========
#
# Daje::Database::Model is ...
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#
#

our $VERSION = "0.05";

sub test  {

}






1;
__END__




#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


Daje::Database::Model - It's the Daje database classes



=head1 SYNOPSIS


    use Daje::Database::Model;



=head1 DESCRIPTION


Daje::Database::Model is ...



=head1 REQUIRES

L<experimental> 

L<v5.40> 


=head1 METHODS


=head1 AUTHOR


janeskil1525 E<lt>janeskil1525@gmail.comE<gt>




=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

