package Daje::Database::Model::Companies;
use Mojo::Base 'Daje::Database::Model::Super::Companies', -base, -signatures;

# Autogenerated class Sun Feb  9 13:11:20 2025
# This class is generated once. Any over rides or special methods should be put here



1;

#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Database::Model::Companies


=head1 DESCRIPTION

Autogenerated class Sun Feb  9 13:11:20 2025
This class is generated once. Any over rides or special methods should be put here


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


=cut

