package Daje::Database::Model::Super::DocumentBuilder;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures;

# Autogenerated class Sat May 31 12:37:07 2025
# Any manual changes to this class will be overwritten next time its generated

has 'fields' => "document_builder_pkey, editnum, insby, insdatetime, modby, moddatetime, document_json, status";
has 'primary_key_name' => "document_builder_pkey";
has 'table_name' => "document_builder";




sub load_pkey($self, $document_builder_pkey) {

    my $result = $self->load_pk(
        $self->table_name,
        $self->fields,
        $self->primary_key_name,
        $document_builder_pkey
    );
    return $result;
}



sub insert_document_builder($self, $data) {
    my $result = $self->insert($self->table_name, $data, $self->primary_key_name);
    return $result;
}


sub update_document_builder($self, $data, $keys) {
    my $result = $self->update($self->table_name, $data, $keys);
    return $result;
}


sub load_list($self, $key_value) {
    my $result = $self->load_a_list(
        $self->table_name,
        $self->fields,
        $key_value
    );
    return $result;
}




1;

