package Daje::Database::View::Super::VUsersInCompany;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures;

# Autogenerated class Sat May 31 12:37:07 2025
# Any manual changes to this class will be overwritten next time its generated

has 'fields' => "'users_pkey', 'support', 'active', 'user_phone', 'username', 'is_admin', 'userid', 'companies_fkey'";
has 'primary_keys' => "users_pkey";
has 'foreign_keys' => "foreign_keys"
has 'view_name' => "v_users_in_company";



sub load_users_pkey($self, $users_pkey ) {

    my $result = $self->load_fkey(
        $self->table_name,
        $self->fields,
        'users_pkey',
        $users_pkey
    );
    return $result;
}

sub load_companies_fkey($self, $companies_fkey ) {

    my $result = $self->load_fkey(
        $self->table_name,
        $self->fields,
        'companies_fkey',
        $companies_fkey
    );
    return $result;
}



