package Daje::Database::View::Super::VCompaniesUsers;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures;

# Autogenerated class Sat May 31 12:37:07 2025
# Any manual changes to this class will be overwritten next time its generated

has 'fields' => "'vatno', 'regno', 'support', 'homepage', 'companies_fkey', 'is_admin', 'company_type_fkey', 'users_fkey', 'company_type', 'active', 'user_phone', 'name', 'userid', 'company_phone', 'username'";
has 'primary_keys' => " ";
has 'foreign_keys' => "foreign_keys"
has 'view_name' => "v_companies_users";



sub load_companies_fkey($self, $companies_fkey ) {

    my $result = $self->load_fkey(
        $self->table_name,
        $self->fields,
        'companies_fkey',
        $companies_fkey
    );
    return $result;
}

sub load_company_type_fkey($self, $company_type_fkey ) {

    my $result = $self->load_fkey(
        $self->table_name,
        $self->fields,
        'company_type_fkey',
        $company_type_fkey
    );
    return $result;
}

sub load_users_fkey($self, $users_fkey ) {

    my $result = $self->load_fkey(
        $self->table_name,
        $self->fields,
        'users_fkey',
        $users_fkey
    );
    return $result;
}



