package Daje::Database::Model::Users;
use Mojo::Base 'Daje::Database::Model::Super::Users', -base, -signatures;

# Autogenerated class Sun Feb  9 13:11:20 2025
# This class is generated once. Any over rides or special methods should be put here

# NAME
# ====
#
#      Daje::Database::Model::Users - It's the DBmanagement class for users
#
#
# REQUIRES
# ========
#
# use Mojo::Base;
# use Daje::Database::Model::Super::Users;
#
# DESCRIPTION
# ===========
#
# Daje::Database::Model::Users is managing users
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#
#

use Digest::SHA qw{sha512_base64};

our $VERSION = "0.01";

sub insert_users($self, $data) {

    $data->{password} = sha512_base64($data->{password}) if exists $data->{password};
    my $result = $self->SUPER::insert_users($data);

    return $result;
}


1;
#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Database::Model::Users


=head1 DESCRIPTION

Autogenerated class Sun Feb  9 13:11:20 2025
This class is generated once. Any over rides or special methods should be put here


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


=cut

